# oneNeuron_pypi
oneNeuron_pypi


## How to use this

```python

from oneNeuron.perceptron import Perceptron
# Get x and y and then below commands
model = Perceptron(eta, epochs)
model.fit(X, y)

```

# Reference -
[Official Python Docs](https://packaging.python.org/tutorials/packaging-projects/)

[Github Docs for Github Actions](https://docs.github.com/en/enterprise-server@3.1/actions/automating-builds-and-tests/building-and-testing-python?learn=continuous_integration)
